#!/bin/bash

#==============================================================================
# AddEmptyPkgs.sh
#==============================================================================

if [[ ! -w /etc/passwd ]] ; then
  echo "Error: Only 'root' can execute this program!"
  exit 1
fi

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/functions/fun-arch.sh
export I_WANT_A_BROKEN_PS EPAGES_KERNEL

. $(dirname $0)/functions/fun-epages.sh
export get_cartridge_version internal_version component_installed

. $(dirname $0)/functions/fun-repoedit.sh
export get_arch_repo enable_repo

. $(dirname $0)/functions/fun-pkg.sh
export pkg_installed

#------------------------------------------------------------------------------
# arguments
#------------------------------------------------------------------------------

BN=${0##*/}

usage() {
  echo "Usage:"
  echo "  $BN [-y] [-v]"
  echo "Options:"
  echo "  -y: assume that the answer to any question which would be asked is yes"
  echo "  -v: verbose output"
  exit 1
}

unset YES VERBOSE
while getopts yv c ; do
  case $c in
    y) YES=-y ;;
    v) VERBOSE=-v ;;
    *) usage ;;
  esac
done

#------------------------------------------------------------------------------
# execute
#------------------------------------------------------------------------------

#..............................................................................
# get VERSION
#..............................................................................

VERSION=$(get_cartridge_version Core)
if [[ -z $VERSION ]] ; then
  REPOSITORY=$(get_arch_repo) || exit 1
  if [[ -n $REPOSITORY ]] ; then
    VERSION=$(rpm -qp $REPOSITORY/epages-version.noarch.rpm --qf '[%{VERSION}\n]')
  fi
fi
if [[ -z $VERSION ]] ; then
  echo "ePages version neither found in Cartridges.d/*.conf: DE_EPAGES::Core="
  echo "nor in $REPOSITORY/epages-version.noarch.rpm, exiting."
  exit 1
fi
if [[ $(internal_version $VERSION) -lt 6009000 ]] ; then
  echo "Error: Cartridges.d/*.conf: DE_EPAGES::Core=$VERSION: void version"
  exit 1
fi

#..............................................................................
# get missing packages
#..............................................................................

PATCH_VRS=${VERSION//./_}
MORE_PKG="patch_$PATCH_VRS patch"
if [[ ${VERSION%.0} = $VERSION ]] ; then
  MORE_PKG="patch_${PATCH_VRS%_*}_0 $MORE_PKG"
fi

[[ $(internal_version $VERSION) -ge 6014000 ]] && MORE_PKG="j $MORE_PKG"
[[ $(internal_version $VERSION) -ge 6017000 ]] && MORE_PKG="nodejs $MORE_PKG"

MISSING_PKG=
for i in appsrv common mysql mysqld perl reqsrv websrv requires webconf $MORE_PKG ; do
  component_installed $i && ! pkg_installed $VERBOSE $i && MISSING_PKG="$MISSING_PKG epages-$i"
done

#..............................................................................
# install missing packages
#..............................................................................

[[ -z $MISSING_PKG ]] && exit 0

WAS_DISABLED=$(enable_repo -e 1 empty base)

case $EPAGES_KERNEL in
  *r) yum $YES install $MISSING_PKG ;;
  *s) zypper install $YES $MISSING_PKG ;;
esac

[[ -n $WAS_DISABLED ]] && enable_repo -e 0 $WAS_DISABLED >/dev/null

# -----------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
