#!/bin/bash

#==============================================================================
# SetRepository.sh
#==============================================================================

if [[ ! -w /etc/passwd ]] ; then
  echo "Error: Only 'root' can execute this program!"
  exit 1
fi

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/functions/fun-arch.sh
export I_WANT_A_BROKEN_PS
export EPAGES_KERNEL

. $(dirname $0)/functions/fun-epages.sh
export get_cartridge_version

. $(dirname $0)/functions/fun-repoedit.sh
export get_arch_repo update_repo_version update_repo_url
export update_repo_arch use_new_repos delete_obsolete_repos

#------------------------------------------------------------------------------
# arguments
#------------------------------------------------------------------------------

BN=${0##*/}

usage() {
  [[ -n $1 ]] && echo -e "Error:\n  $1"
  echo "Usage:"
  echo "  $BN [-r REPOSITORY] [-b VERSION]"
  echo "Options:"
  echo "  -r: set repository URL in ePages repo files"
  echo "  -b: set version in ePages repo files"
  echo "  -i: initial repository configuration"
  echo "  -X: do not update repository cache"
  exit 1
}

[ $# -eq 0 ] && usage "at least one argument required"

unset REPOSITORY VERSION INITIAL SKIP_UPDATE_CACHE
while getopts r:b:iX c ; do
  case $c in
    r) REPOSITORY=$OPTARG ;;
    b) VERSION=$OPTARG ;;
    i) INITIAL=1 ;;
    X) SKIP_UPDATE_CACHE=1 ;;
    *) usage ;;
  esac
done

if [[ -n $REPOSITORY ]] ; then
  case $REPOSITORY in
    http://*|https://*|ftp://*|file://*) true
    ;;
    *) REPOSITORY=$(cd $REPOSITORY && pwd) || usage "-r: invalid argument"
       REPOSITORY=file://$REPOSITORY
    ;;
  esac
  REPOSITORY=$(echo "$REPOSITORY" | sed -r 's,/+$,,')
fi

#------------------------------------------------------------------------------
# execute
#------------------------------------------------------------------------------

UPDATE_CACHE=
if [[ $EPAGES_KERNEL = ${EPAGES_KERNEL%d} && -n $INITIAL ]] ; then
  use_new_repos
  delete_obsolete_repos
  update_repo_arch setup base arch
  UPDATE_CACHE=1
fi

case $EPAGES_KERNEL in
  *r|*s) ls /etc/yum.repos.d/epages-*.repo >/dev/null || exit 1
      cd /etc/yum.repos.d || exit 1
      REPOS=$(echo epages-*.repo | sed 's,\.repo,,g;s,epages-,,g')
  ;;
  *d) ls  /etc/apt/sources.list.d/epages.list >/dev/null || exit 1
  ;;
  *) exit 1
  ;;
esac

if [[ $EPAGES_KERNEL = ${EPAGES_KERNEL%d} && ( -n $VERSION || -n $REPOSITORY ) ]] ; then
  # update yum repo
  mkdir -m 755 -p /etc/yum/vars
  [[ -n $VERSION ]] && echo $VERSION > /etc/yum/vars/EPAGES_VERSION
  [[ -n $REPOSITORY ]] && echo $REPOSITORY > /etc/yum/vars/EPAGES_REPO
  update_yum_repo $REPOS
  UPDATE_CACHE=1
elif [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%d} ]] ; then
  # update apt repo
  [[ -n $VERSION ]] && update_repo_version $VERSION
  [[ -n $REPOSITORY ]] && update_repo_url $REPOSITORY
  UPDATE_CACHE=1
fi

[[ -z $UPDATE_CACHE ]] && exit 0

# update cache files
case $EPAGES_KERNEL in
  *r) rm -rf /var/cache/yum/epages-*
  ;;
  *s) rm -rf /var/cache/zypp/packages/epages-*
  ;;
esac

[[ -n $SKIP_UPDATE_CACHE ]] && exit 0
 
# update repository cache
case $EPAGES_KERNEL in
  *r) yum --enablerepo='epages-*' --disablerepo 'epages*-6.*' clean metadata 2>/dev/null
  ;;
  *s) ( zypper clean -m ; zypper refresh ) 2>/dev/null
  ;;
  *d) apt-get -y update
  ;;
esac

# -----------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
exit 0
