#!/bin/bash

# -----------------------------------------------------------------
# variables
# -----------------------------------------------------------------

. /etc/default/epages6

BN=${0##*/}
INI_CONFIG=/var/epages/ini-config.sh

#mongo daemon name (used for stop/start)
#mongod_name() sourced by ../functions/fun-java.sh via /etc/default/epages6
MONGOD=$(mongod_name)

# argument defaults
MONGO_CONF_FILE=${MONGOD_CONF:-"/etc/$MONGOD.conf"}

# -----------------------------------------------------------------
# arguments
# -----------------------------------------------------------------

usage() {
  [[ $# -gt 0 ]] && echo -e "Error:\n  $@"
  echo "Usage:"
  echo "  $0 [-c mongodb.conf]"
  echo "Description:"
  echo "  Tests mongodb authentication by checking mongodb.conf."
  echo "  If authentication is already enabled or enabling"
  echo "  authentication is not possible, returns false; otherwise true."
  echo "Options:"
  echo "  -c: mongodb config file (default: $MONGO_CONF_FILE)"
  echo "Examples:"
  echo "  $0"
  echo "  $0 -c /etc/mongo_xyz.conf"
  exit 1
}

#get options from command line
while getopts f: char; do
case $char in
    c) MONGO_CONF_FILE=$OPTARG ;;
    *) usage ;;
  esac
done
shift `expr $OPTIND - 1`

[[ $# -ne 0 ]] && usage "$BN: No extra arguments allowed: $@"

# -----------------------------------------------------------------
# execution
# -----------------------------------------------------------------

# won't enable auth if mongod.conf not found
[[ -f "$MONGO_CONF_FILE" ]] || exit 1

# won't enable auth if epagesj.conf not found
EPAGESJ=${EPAGESJ:-$EPAGES/j}
EPAGESJ_CONF=${EPAGESJ_CONFIG:-$EPAGESJ/conf}/epagesj.conf
[[ -f "$EPAGESJ_CONF" ]] || exit 1

# won't enable auth if epagesj has more than one mongo server
# i.e. [Mongo]hosts= contains at least one ','
NUMBER_OF_MONGO_HOSTS=$($INI_CONFIG -f "$EPAGESJ_CONF" -s Mongo -k hosts -G | tr , '\n' | sort | uniq | wc -l)
[[ $NUMBER_OF_MONGO_HOSTS -gt 1 ]] && exit 1

# won't enable auth if mongod.conf has already keyFile or auth
[[ -n $($INI_CONFIG -f $MONGO_CONF_FILE -k keyFile -G) ]] && exit 1
[[ -n $($INI_CONFIG -f $MONGO_CONF_FILE -k auth -G) ]] && exit 1

# otherwise allow authentication setting
exit 0
