#!/bin/bash

# -----------------------------------------------------------------
# variables
# -----------------------------------------------------------------

BN=${0##*/}
OUTPUT=export.txt
MONGO_CMD=mongo
MONGOEXPORT=mongoexport

# -----------------------------------------------------------------
# arguments
# -----------------------------------------------------------------

usage() {
  [[ $# -gt 0 ]] && echo -e "Error:\n  $@"
  echo "Usage:"
  echo "  $0 -d DATABASE [-o OUTPUT]"
  echo "Options:"
  echo "  -d: name of the data base"
  echo "  -o: output file (default: $OUTPUT)"
  echo "Example:"
  echo "  $0 -d epagesj -o $OUTPUT"
  exit 1
}

unset DATABASE
while getopts d:o: i ; do
  case $i in
    d) DATABASE=$OPTARG ;;
    o) OUTPUT=$OPTARG ;;
    *) usage ;;
  esac
done
shift `expr $OPTIND - 1`

[[ -z $DATABASE ]] && usage "$BN: Option -d missing"
[[ $# -ne 0 ]] && usage "$BN: No extra arguments allowed: $@"

#check if mongo is installed
type $MONGO_CMD || exit 1

# -----------------------------------------------------------------
# get collection names from database
# -----------------------------------------------------------------

collection_names=$($MONGO_CMD $DATABASE --quiet --eval 'db.getCollectionNames()')
if [[ $? -ne 0 ]] ; then
  echo $collection_names
  exit 1
fi

# -----------------------------------------------------------------
# for each collection: export data to output file
# -----------------------------------------------------------------

mkdir -p -m 755 $(dirname $OUTPUT) || exit 1
echo "" > $OUTPUT || exit 1

#check if mongoexport installed
type $MONGOEXPORT || exit 1

for collection in ${collection_names//,/ } ; do
  echo -e "----------\n$collection\n----------"
  $MONGOEXPORT --db epagesj --collection $collection || exit 1
done >> $OUTPUT

exit 0
