#!/bin/bash

# -----------------------------------------------------------------
# variables
# -----------------------------------------------------------------

BN=${0##*/}
MONGO_CMD=mongo

# -----------------------------------------------------------------
# arguments
# -----------------------------------------------------------------

usage() {
  [[ $# -gt 0 ]] && echo -e "Error:\n  $@"
  echo "Usage:"
  echo "  $0 -d dbname -u dbuser"
  echo "Description:"
  echo "  returns success if dbname has dbuser, otherwise failure"
  echo "Options:"
  echo "  -d : database name (required)"
  echo "  -u : user name (required)"
  echo "Example:"
  echo "  $0 -d admin -u siteRootAdmin"
  exit 1
}

#get options from command line
unset DB_NAME DB_USER
while getopts d:u: char; do
case $char in
    d) DB_NAME=$OPTARG ;;
    u) DB_USER=$OPTARG ;;
    *) usage ;;
  esac
done
shift `expr $OPTIND - 1`

[[ $# -ne 0 ]] && usage "$BN: No extra arguments allowed: $@"
[[ -n "$DB_NAME" ]] || usage "$BN: Option missing: -d"
[[ -n "$DB_USER" ]] || usage "$BN: Option missing: -u"

# -----------------------------------------------------------------
# db.system.users.find
# -----------------------------------------------------------------

STATEMENT="db.system.users.find({user:'$DB_USER'}).count()"

OUTPUT=$($MONGO_CMD $DB_NAME --quiet --eval "$STATEMENT")
RESULT=$?

[[ $RESULT = 0 ]] || { echo $OUTPUT 1>&2; exit $RESULT; }
[[ $OUTPUT -ge 1 ]] && exit 0 || exit 1
