#!/bin/bash

# -----------------------------------------------------------------
# variables
# -----------------------------------------------------------------

BN=${0##*/}
MONGO_CMD=mongo

# -----------------------------------------------------------------
# arguments
# -----------------------------------------------------------------

usage() {
  [[ $# -gt 0 ]] && echo -e "Error:\n  $@"
  echo "Usage:"
  echo "  $0 -d dbname -u dbuser -p password"
  echo "Description:"
  echo "  updates user password in mongodb"
  echo "Options:"
  echo "  -d : database name (required)"
  echo "  -u : user name (required)"
  echo "  -p : user password (required)"
  echo "Example:"
  echo "  $0 -d admin -u siteRootAdmin -p secret"
  exit 1
}

#get options from command line
unset DB_NAME DB_USER DB_PW
while getopts d:u:p: char; do
case $char in
    d) DB_NAME=$OPTARG ;;
    u) DB_USER=$OPTARG ;;
    p) DB_PW=$OPTARG ;;
    *) usage ;;
  esac
done
shift `expr $OPTIND - 1`

[[ -z $DB_NAME ]] && usage "$BN: Option -d missing"
[[ -z $DB_USER ]] && usage "$BN: Option -u missing"
[[ -z $DB_PW ]] && usage "$BN: Option -p missing"
[[ $# -ne 0 ]] && usage "$BN: No extra arguments allowed: $@"

# -----------------------------------------------------------------
# update password by changeUserPassword
# -----------------------------------------------------------------

# quote arguments
DB_USER="\"$DB_USER\""
DB_PW="\"$DB_PW\""

STATEMENT="db.changeUserPassword($DB_USER, $DB_PW)"

# -----------------------------------------------------------------
# wait until mongod has started
# -----------------------------------------------------------------

RESULT=1 ; COUNT=0
while [[ $COUNT -lt 5 ]] ; do
  COUNT=$(($COUNT + 1))
  $MONGO_CMD $DB_NAME --quiet --eval "$STATEMENT" 2>/tmp/$USER-mongo_pass.err
  RESULT=$?
  if grep -q . /tmp/$USER-mongo_pass.err ; then
    RESULT=1
    # break loop if other error than 'connect failed'
    grep -q 'connect failed' /tmp/$USER-mongo_pass.err || break
  fi
  [[ $RESULT = 0 ]] && break
  sleep 8
done

exit $RESULT
