#!/bin/bash

#==============================================================================
# architecture
#==============================================================================

fun_arch_sourced=1

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

[[ -n $fun_linux_sourced ]] || . $(dirname $BASH_SOURCE)/fun-linux.sh
export is_positive

#------------------------------------------------------------------------------
# provide
#------------------------------------------------------------------------------

export NOHUP AWK EPAGES_KERNEL EPAGES_ARCH
export local_timezone u_sleep nss_softokn_is_compatible

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

#..............................................................................
# NOHUP AWK
#..............................................................................
NOHUP=nohup
AWK=awk

#..............................................................................
# EPAGES_KERNEL
#..............................................................................
unset EPAGES_KERNEL
UNAME_R=$(uname -r)
cnt=0
for i in ${UNAME_R//[-.]/ } ; do
  EPAGES_KERNEL=$EPAGES_KERNEL.$i
  cnt=$(($cnt + 1))
  [[ $cnt -ge 3 ]] && break
done
EPAGES_KERNEL=${EPAGES_KERNEL#.}

if [[ -f /etc/redhat-release ]] ; then
  EPAGES_KERNEL=${EPAGES_KERNEL}r
elif [[ -f /etc/SuSE-release ]] ; then
  [[ $EPAGES_KERNEL != ${EPAGES_KERNEL#3.0.} ]] && EPAGES_KERNEL=2.6.32
  EPAGES_KERNEL=${EPAGES_KERNEL}s
elif [[ -f /etc/debian_version ]] ; then
  EPAGES_KERNEL=3.2.0d
fi

#..............................................................................
# I_WANT_A_BROKEN_PS LANG
#..............................................................................
export I_WANT_A_BROKEN_PS
unset I_WANT_A_BROKEN_PS

#..............................................................................
# LC_ALL LC_CTYPE LC__FASTMSG
#..............................................................................
if [[ $EPAGES_KERNEL = ${EPAGES_KERNEL%d} ]] ; then
  export LC_ALL LC_CTYPE LC__FASTMSG 2>/dev/null
  unset LC_ALL LC_CTYPE LC__FASTMSG 2>/dev/null
fi

#..............................................................................
# EPAGES_ARCH
#..............................................................................
[[ $(uname -m) = x86_64 ]] && EPAGES_ARCH=x86_64 || EPAGES_ARCH=i386

#..............................................................................
# local_timezone
#..............................................................................
local_timezone () {
  local USAGE='
syntax: local_timezone
returns: local timezone dependig on:
         1. environment variable TZ
         2. /etc/localtime
         3. /etc/sysconfig/clock
'
  [[ $# = 0 ]] || { echo "$USAGE" 1>&2; return 1; }

  # 1st try: environment variable TZ
  [[ -n $TZ ]] && { echo "$TZ" ; return; }

  # 2nd try: compare files in /usr/share/zoneinfo with /etc/localtime
  if [[ -f /etc/localtime ]] && pushd /usr/share/zoneinfo >/dev/null 2>&1 ; then
    find [A-Z]*/* -maxdepth 0 ! -type d 2>/dev/null | sed 's,^Etc/, Etc/,' | sort -r \
    | while read i ; do
      while [[ $i != ${i# } ]] ; do i=${i# } ; done
      if cmp -s "$i" /etc/localtime ; then echo "$i"; exit 1; fi
    done
    local RESULT=$?
    popd >/dev/null
    [[ $RESULT != 0 ]] && return
  fi

  # 3rd try: /etc/sysconfig/clock
  if [[ -f /etc/sysconfig/clock ]] ; then
    unset TIMEZONE ZONE
    . /etc/sysconfig/clock
    if grep -q TIMEZONE /etc/init.d/boot.clock 2>/dev/null ; then
      [[ -n $TIMEZONE ]] && { echo "$TIMEZONE"; return; }
    else
      [[ -n $ZONE ]] && { echo "$ZONE"; return; }
      [[ -n $TIMEZONE ]] && { echo "$TIMEZONE"; return; }
    fi
  fi
}

#..............................................................................
# u_sleep
#..............................................................................
u_sleep () {
  local USAGE='
syntax: u_sleep [number]
description: sleep some number of microseconds (by using usleep or sleepenh)
'
  [[ $1 != ${1#-} ]] && { echo "$USAGE" 1>&2; return 1; }

  local NUMBER=${1:-0}
  if [[ $NUMBER != 0 ]] && ! is_positive $NUMBER ; then
    echo -e "ERROR: not a positive number: $NUMBER$USAGE" 1>&2; return 1
  fi

  if [[ -n $(type -t usleep) ]] ; then
    # used by redhat/suse
    usleep $NUMBER
  elif [[ -n $(type -t sleepenh) ]] ; then
    # used by debian
    sleepenh $(echo "scale=6;$NUMBER/1000000" | bc) >/dev/null
  else
    echo -e "ERROR: neither usleep nor sleepenh found$USAGE" 1>&2; return 1
  fi
}

#..............................................................................
# nss_softokn_is_compatible
#..............................................................................
nss_softokn_is_compatible () {
  local USAGE='
syntax: nss_softokn_is_compatible
description: test if nss-softokn and nss-softokn-freebl are compatible
             see https://bugzilla.redhat.com/show_bug.cgi?id=1182337
returns: success, if operating system is not CentOS 6
         success, if both nss-softokn and nss-softokn-freebl are installed
         success, if neither nss-softokn nor nss-softokn-freebl is installed
         failure otherwise
output:  all found nss-softokn* RPMs
'
  [[ -n $1 ]] && { echo "$USAGE" 1>&2; return 1; }

  [[ $EPAGES_KERNEL = 2.6.32r ]] || return 0

  local RET
  for i in i686 x86_64 ; do
    rpm --quiet -q nss-softokn.$i && echo -n "nss-softokn.$i "
    local has_softokn=$?
    rpm --quiet -q nss-softokn-freebl.$i && echo -n "nss-softokn.$i "
    local has_freebl=$?
    [[ $has_freebl != $has_softokn ]] && { RET=1; continue; }
    [[ $RET = 1 ]] || RET=0
  done

  return $RET
}

#------------------------------------------------------------------------------
# end
# -----------------------------------------------------------------------------
