#!/bin/bash

#==============================================================================
# terminal
#==============================================================================

fun_term_sourced=1

#------------------------------------------------------------------------------
# provide
#------------------------------------------------------------------------------

export column em R G B Y P C
export COLUMNS

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

COLUMNS=1024

#..............................................................................
# column
#..............................................................................

column() {
  local USAGE='
syntax: column [START]
description: set start column COL for echo (default: 0)
'
  [[ $# -gt 1 || $1 != ${1#-} ]] && { echo "$USAGE" 1>&2; return 1; }

  [[ -z $TERM || $TERM = raw || $TERM = dumb ]] && { echo -n "    "; return; }
  local COL=$1
  echo -en "\\033[${COL:-0}G"
}

#..............................................................................
# em
#..............................................................................

em() {
  local USAGE='
syntax: em [OPTIONS] [COLOR] [BGCOLOR] STRING
description: em(phasize) text on terminal
OPTIONS: -s(trong) -d(im) -u(nderline) -i(nverse) -h(idden) -x(out)
COLOR:   -L(black) -R(ed) -G(reen) -B(lue) -Y(ellow) -P(ink) -C(yan) -W(hite)
BGCOLOR: -l(black) -r(ed) -g(reen) -b(lue) -y(ellow) -p(ink) -c(yan) -w(hite)
'
  [[ $# -le 1 ]] && { echo "$USAGE" 1>&2; return 1; }

  local COLOR=39 # default
  local BGCOLOR=49 # default
  local OPTIONS
  local OPTIND=0
  while getopts sduihxLRGBYPCWlrgbypcw c $@ ; do
    case $c in
      s) OPTIONS="$OPTIONS\\033[1m" ;; # strong
      d) OPTIONS="$OPTIONS\\033[2m" ;; # dim
      u) OPTIONS="$OPTIONS\\033[4m" ;; # underline
      i) OPTIONS="$OPTIONS\\033[7m" ;; # inverse
      h) OPTIONS="$OPTIONS\\033[8m" ;; # hidden
      x) OPTIONS="$OPTIONS\\033[9m" ;; # crossout
      L) COLOR=30 ;; # black
      R) COLOR=31 ;; # red
      G) COLOR=32 ;; # green
      B) COLOR=34 ;; # blue
      Y) COLOR=33 ;; # yellow
      P) COLOR=35 ;; # pink
      C) COLOR=36 ;; # cyan
      W) COLOR=37 ;; # white
      l) BGCOLOR=40 ;; # black
      r) BGCOLOR=41 ;; # red
      g) BGCOLOR=42 ;; # green
      b) BGCOLOR=44 ;; # blue
      y) BGCOLOR=43 ;; # yellow
      p) BGCOLOR=45 ;; # pink
      c) BGCOLOR=46 ;; # cyan
      w) BGCOLOR=47 ;; # white
    esac
  done
  shift $(($OPTIND - 1))

  [[ -z $TERM || $TERM = raw || $TERM = dumb ]] && { echo "$@"; return; }
  echo -en "$OPTIONS\\033[${BGCOLOR};${COLOR}m$@\\033[m"
}

#..............................................................................
# R G B Y P C
#..............................................................................

R() { em -R $@ ; }
G() { em -G $@ ; }
B() { em -B $@ ; }
Y() { em -Y $@ ; }
P() { em -P $@ ; }
C() { em -C $@ ; }

#------------------------------------------------------------------------------
# end
# -----------------------------------------------------------------------------
