#!/bin/bash

#==============================================================================
# epages-requires.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_DO_PATCH

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-pkg.sh
export pkg_instance

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-requires-post
#..............................................................................
epages-requires-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-requires-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-requires package'
    echo 'example: epages-requires-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ -n $EPAGES_SKIP_SPEC ]] && return 0
  [[ -f /tmp/nss_softokn.tar ]] || return 0

  # do nothing if rpm program works
  if rpm --quiet -q epages-release 2>/dev/null ; then
    mv /tmp/nss_softokn.tar /tmp/nss_softokn.tar.~$$~
    return $?
  fi

  # if tar file to backup softokn libraries was created before
  # restore these libraries by unpacking the tar
  pushd / >/dev/null
  tar xf /tmp/nss_softokn.tar
  mv /tmp/nss_softokn.tar /tmp/nss_softokn.tar.~$$~
  popd >/dev/null

  return $?
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  post)    epages-requires-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
