#!/bin/bash

#==============================================================================
# epages-webconf.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_INSTALL_VERSION

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export update_epages_environment set_epages_conf
export get_cartridge_version internal_version etc_default

. $(dirname $0)/fun-httpd.sh
export setup_etc_apache set_apache_envvars disable_eproot_apache 
export add_dummy_cert start_epages_apache mkdir_epages_apache
export set_selinux4httpd

. $(dirname $0)/fun-pkg.sh
export pkg_instance

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-webconf-post
#..............................................................................
epages-webconf-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-webconf-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-webconf package'
    echo 'example: epages-webconf-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ -n $EPAGES_SKIP_SPEC ]] || update_epages_environment -i "$1"

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  [[ -f $ETC_DEFAULT ]] || { ls -l $ETC_DEFAULT; exit 1; } 
  . $ETC_DEFAULT

  if [[ -z $EPAGES_SKIP_SPEC ]] ; then
    rm -f "$EPAGES"/bin/dummycert.sh "$EPAGES"/bin/use-local-httpd.sh
    rm -f "$EPAGES"/bin/set-local-ips.sh "$EPAGES"/bin/update-rewrite-conf.sh
    rm -f "$EPAGES"/WebAdapter/zzz-epages-*.ept

    local INSTANCE_ORIG=$INSTANCE
    if [[ $INSTANCE != first && ! -f /etc/debian_version ]] ; then
      local CORE_VERSION=$(get_cartridge_version Core)
      [[ -n ${CORE_VERSION//[0-9.]/} ]] && CORE_VERSION=
      local INTERNAL_VERSION=${CORE_VERSION:+$(internal_version $CORE_VERSION)}
      [[ ${INTERNAL_VERSION:-0} -lt 6017005 ]] && INSTANCE=first
    fi

    disable_eproot_apache
  fi

  if [[ $INSTANCE = first ]] ; then
    setup_etc_apache epages
    set_apache_envvars
    . /etc/apache2-epages/envvars
    add_dummy_cert $APACHE_SERVER_NAME
    if [[ -z $EPAGES_SKIP_SPEC ]] ; then
      local SCRIPT=$EPAGES_CARTRIDGES/DE_EPAGES/WebInterface/Scripts/patchWebInterface.pl
      [[ $INSTANCE_ORIG != first && -f $SCRIPT ]] && $PERL $SCRIPT
    fi
  else
    . /etc/apache2-epages/envvars
  fi

  # if directory exists this is not a first installation
  [[ -d "$EPAGES_WEBROOT"/StoreTypes/ ]] && INSTANCE=
  [[ -n $EPAGES_SKIP_SPEC ]] && INSTANCE=
  mkdir_epages_apache $INSTANCE

  set_selinux4httpd

  [[ -n $EPAGES_SKIP_SPEC ]] && return 0

  set_epages_conf $APACHE_SERVER_NAME $APACHE_PORT

  [[ $INSTANCE_ORIG = first ]] && start_epages_apache || start_epages_apache reload
  return 0
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-webconf-pre $2 $3 ; exit $? ;;
  post) epages-webconf-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
