#!/bin/bash

if [[ $# -eq 0 ]] ; then
  echo "Usage:"
  echo "  $0 [OPTIONS] RPM1 RPM2 ..."
  echo "Options:"
  echo "  --update-only: only update the installed RPM"
  echo "  --update: update or install the RPM"
  echo "  (none): only install RPM if not installed yet"
  echo "Example:"
  echo "  $0 graphviz nodejs"
  exit 1
fi

PATH=sh/EPAGES_RELEASE/var/epages:/var/epages:$PATH

. functions.sh

started_by_rpm $$ && exit 0

if [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%d} ]] ; then
  unset PERL5LIB
  INSTALLER=apt-get ; YES=-y ; unset ZES
elif [[ $KERNEL = ${KERNEL%s} && $EPAGES_KERNEL = ${EPAGES_KERNEL%s} ]] ; then
  INSTALLER=yum ; YES=-y ; unset ZES
else
  INSTALLER=zypper ; ZES=-y ; unset YES
  zypper mr -d epages-setup
fi

unset DISABLE_AFTER ENABLE_AFTER
for i in $ENABLE_REPO ; do
  if [[ $INSTALLER = yum ]] ; then
    YES="$YES --enablerepo $i"
  elif [[ $INSTALLER = zypper ]] ; then
    ZES="$ZES -r $i"
    zypper lr $i > /tmp/$$.pid1
    zypper mr -e $i
    zypper lr $i > /tmp/$$.pid2
    cmp -s /tmp/$$.pid1 /tmp/$$.pid2 || DISABLE_AFTER="$DISABLE_AFTER $i"
    rm -f /tmp/$$.pid1 /tmp/$$.pid2
  fi
done
for i in $DISABLE_REPO ; do
  if [[ $INSTALLER = yum ]] ; then
    YES="$YES --disablerepo $i"
  elif [[ $INSTALLER = zypper ]] ; then
    zypper lr $i > /tmp/$$.pid1
    zypper mr -d $i
    zypper lr $i > /tmp/$$.pid2
    cmp -s /tmp/$$.pid1 /tmp/$$.pid2 || ENABLE_AFTER="$ENABLE_AFTER $i"
    rm -f /tmp/$$.pid1 /tmp/$$.pid2
  fi
done

case $1 in
  --update-only) DO=update ; shift ;;
  --update) DO=install_or_update ; shift ;;
  *) DO=install ;;
esac

[[ $INSTALLER = zypper ]] && zypper refresh

unset CLEAN_ALL

for RPM in $@ ; do
  IS_INSTALLED=
  if [[ $INSTALLER = apt-get ]] ; then
    dpkg --status $RPM >/dev/null 2>&1 && IS_INSTALLED=1
  else
    rpm --quiet -q $RPM >/dev/null 2>&1 && IS_INSTALLED=1
  fi
  if [[ $IS_INSTALLED ]] ; then
    [[ $DO = install ]] && continue
    # workaround: sometimes file conflicts occur
    if [[ $INSTALLER = zypper ]] ; then
      zypper list-updates | awk "/ $RPM /{exit 123}"
      [[ $? = 123 ]] || continue # up-to-date
    elif [[ $INSTALLER = yum ]] ; then
      yum check-update $YES 2>/dev/null | awk "/^$RPM\./{exit 123}"
      [[ $? = 123 ]] || continue # up-to-date
    fi
    if [[ $INSTALLER != apt-get ]] ; then
      case $RPM in
        epages-j|epages-nodejs)
          rpm -e --nodeps $RPM ; [[ $INSTALLER = yum ]] && CLEAN_ALL=1 ;;
        epages-*)
          true ;;
        *)
          rpm -e --nodeps $RPM ; [[ $INSTALLER = yum ]] && CLEAN_ALL=1 ;;
      esac
    fi
  else
    [[ $DO = update ]] && continue
  fi
  echo "$INSTALLER $YES install $ZES $RPM"
  eval $INSTALLER $YES install $ZES $RPM || exit 1
done

if [[ $INSTALLER = zypper ]] ; then
  for i in $DISABLE_AFTER ; do
    zypper mr -d $i
  done
  for i in $ENABLE_AFTER ; do
    zypper mr -e $i
  done
elif [[ $INSTALLER = yum ]] ; then
  [[ -n $CLEAN_ALL ]] && yum clean all
fi

exit 0
