#!/bin/env bash

BN=${0##*/}

usage() {
  ( echo "Usage:"
    echo "  $BN { SYMLINK | SYMLINK.lnk }"
    echo "Arguments:"
    echo "  SYMLINK    : copy to SYMLINK.lnk, then unties SYMLINK"
    echo "  SYMLINK.lnk: ties SYMLINK.lnk, then move to SYMLINK" ) 1>&2
  exit 1
}

FILE=$1
[[ -z $FILE ]] && usage

# argument exists and is a symlink
[[ -h $FILE ]] || exit 0

if [[ $FILE = ${FILE%.lnk} ]] ; then
  # if argument does not end in .lnk
  # then change it from symlink to file
  # and remember the symlink target in .lnk

  LINK=$FILE.lnk # e.g.: LINK=/etc/default/epages6.lnk
  rm -f $LINK    # e.g.: rm -f /etc/default/epages6.lnk

  # remember the symlink target
  mv $FILE $LINK # e.g.: mv /etc/default/epages6 /etc/default/epages6.lnk
  # now, /etc/default/epages6.lnk is a symlink

  # copy the contents of symlink into file $FILE
  # e.g. cp -pL /etc/default/epages6.lnk /etc/default/epages6
  cp -pL $LINK $FILE || exit 1
  # now, $FILE (e.g. /etc/default/epages6) is a file
else
  # if argument ends in .lnk
  # then change it from file to symlink

  LINK=$FILE # e.g. LINK=/etc/default/epages6.lnk
  FILE=${FILE%.lnk} # e.g. FILE=/etc/default/epages6
  if [[ -e $FILE ]] ; then
    # if $FILE and $LINK differ
    if [[ $(readlink -f $FILE) != $(readlink -f $LINK) ]] ; then
      # copy the contents of $FILE into symlink $LINK
      # e.g. cp -pL /etc/default/epages6 /etc/default/epages6.lnk
      cp -pL $FILE $LINK || exit 1
    fi
    rm -f $FILE || exit 1 # e.g.: rm -f /etc/default/epages6
  fi
  # e.g. cp -pL /etc/default/epages6 /etc/default/epages6.lnk
  mv $LINK $FILE || exit 1
  # now, $FILE (e.g. /etc/default/epages6) is a symlink
fi

exit 0
