#!/bin/env bash

BN=${0##*/}
DN=$(cd $(dirname $0) && pwd)

usage() {
  ( echo "Usage:"
    echo "  $BN -f file -p patch.ini [-i]"
    echo "Options:"
    echo "  -f: file to patch"
    echo "  -p: ini file with patch instructions"
    echo "  -i: edit file in place" ) 1>&2
  exit 1
}

[[ $# -eq 0 ]] && usage

unset FILE CONF INPLACE
while getopts f:p:i c ; do
  case $c in
    f) FILE=$OPTARG ;;
    p) CONF=$OPTARG ;;
    i) INPLACE=1 ;;
    *) usage ;;
  esac
done

[[ -z $FILE || -z $CONF ]] && usage
ls "$FILE" "$CONF" >/dev/null || usage

PERL5LIB=
PATH=$DN:/var/epages:/usr/bin:/bin:$PATH
for i in perl ini-config.sh ; do
  type $i >/dev/null || exit $?
done

export FROM="$FILE".~$$~
cp -p "$FILE" "$FROM" || exit 1

ini-config.sh -f "$CONF" -g | while read SECTION ; do
  cp -p "$FROM" "$FROM".in
  egrep -q -- "$SECTION" "$FROM" && continue # already changed
  export SUBST=$(ini-config.sh -f "$CONF" -s "$SECTION" -k subst -g)
  export BY=$(ini-config.sh -f "$CONF" -s "$SECTION" -k by -g)
  [[ -z $SUBST ]] && continue # section incomplete

  if [[ $SUBST = '^' ]] ; then   # prepend lines
    echo "$BY" > "$FROM"
    cat "$FROM".in >> "$FROM"
  elif [[ $SUBST = '$' ]] ; then # append lines
    cat "$FROM".in > "$FROM"
    echo "$BY" >> "$FROM"
  else                           # change lines
    perl -e '$/ = undef;
# evaluate $ENV{...} (not if prepended by backslash)
foreach (qw(SUBST BY)) {
  while ($ENV{$_} =~ s%\\\\(_DBLBS_camoes_)*(\$ENV\{.+?\})%_DBLBS_camoes_$1$2%gs) {1;}
  $ENV{$_} =~ s%\\((_DBLBS_camoes_)+)(\$ENV\{.+?\})%$1\\$3%gs;
  $ENV{$_} =~ s%(?<!\\)\$ENV\{(.+?)\}%$ENV{$1}%gs;
  $ENV{$_} =~ s%_DBLBS_camoes_%\\%gs;
}
while(<>) { s%$ENV{SUBST}%$ENV{BY}%gs; print;}' "$FROM".in > "$FROM"
  fi
done

[[ -z $INPLACE ]] && cat "$FROM" || cat "$FROM" > "$FILE"
rm -f "$FROM"*

exit 0
