#!/bin/bash

##############################################################################
# this script tests with shunit2 methods
# following shell script from the ../t dir
##############################################################################

SCRIPT_TO_TEST=mongo_create_user.sh

# die if shunit2 not found
type shunit2 && SHUNIT2=$(type -p shunit2) || exit 1
echo -e "testing: $0"

# test script directory (/var/epages/t)
TEST_DIR=$(cd $(dirname $0) && pwd)
# directory to test (/var/epages/bin)
BIN_DIR=${TEST_DIR%/*}/bin
SCRIPT_TO_TEST=$BIN_DIR/$SCRIPT_TO_TEST
echo -e "script to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function setUp() {
  TEST_DB='test'
  TEST_USER='tony3'
  MONGO="mongo"
}

function oneTimeTearDown() {
  $MONGO $TEST_DB --quiet --eval "db.removeUser('$TEST_USER')"
}

##############################################################################
# define functions                                                           #
##############################################################################

function test_script_syntax() {
  bash -n $SCRIPT_TO_TEST
  assertTrue "Execution failed ($?): bash -n $SCRIPT_TO_TEST" $?

  echo -e "done.\n"
}

function test_arguments() {
  $SCRIPT_TO_TEST >/dev/null 2>&1
  assertFalse "Option -d must exist: $SCRIPT_TO_TEST" $?
  $SCRIPT_TO_TEST -d x -u y -p z e>/dev/null 2>&1
  assertFalse "No extra arguments allowed: $SCRIPT_TO_TEST -d x y" $?

  echo -e "done.\n"
}

function test_if_programs_exist() {
  type mongo
  assertTrue "Execution failed ($?): type $program" $?

  echo -e "done.\n"
}

##############################################################################
# test user creation                                                             #
##############################################################################

function test_user_creation() {

  $SCRIPT_TO_TEST -d $TEST_DB -u $TEST_USER -p 123456 -r 'dbAdmin'
  assertTrue 'could not run script mongo_create_user.sh' $?

  USER_COUNT=$($MONGO $TEST_DB --quiet --eval "db.system.users.find({user:'$TEST_USER'}).count()")
  assertEquals "Could not create user '$TEST_USER'." 1 $USER_COUNT

  echo -e "done.\n"
}

##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
