#!/bin/bash

##############################################################################
# this script tests with shunit2 methods
# following shell script from the ../t dir
##############################################################################

SCRIPT_TO_TEST=mongo_export.sh

# die if shunit2 not found
type shunit2 && SHUNIT2=$(type -p shunit2) || exit 1
echo -e "testing: $0\n"

# test script directory (/var/epages/t)
TEST_DIR=$(cd $(dirname $0) && pwd)
# directory to test (/var/epages/bin)
BIN_DIR=${TEST_DIR%/*}/bin
SCRIPT_TO_TEST=$BIN_DIR/$SCRIPT_TO_TEST
echo -e "script to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function setUp() {
  OUTPUT=test.txt
}

function tearDown() {
  rm -f $OUTPUT
}

##############################################################################
# define functions                                                           #
##############################################################################

function test_script_syntax() {
  bash -n $SCRIPT_TO_TEST
  assertTrue "Execution failed ($?): bash -n $SCRIPT_TO_TEST" $?

  echo -e "done.\n"
}

function test_arguments() {
  $SCRIPT_TO_TEST >/dev/null 2>&1
  assertFalse "Option -d must exist: $SCRIPT_TO_TEST" $?
  $SCRIPT_TO_TEST -d x y >/dev/null 2>&1
  assertFalse "No extra arguments allowed: $SCRIPT_TO_TEST -d x y" $?

  echo -e "done.\n"
}

function test_if_programs_exist() {
  for program in mongo mongoexport ; do
    type $program
    assertTrue "Execution failed ($?): type $program" $?
  done

  echo -e "done.\n"
}

function test_export_without_auth() {
  assertTrue "No such file: $SCRIPT_TO_TEST" "test -f $SCRIPT_TO_TEST"
  assertTrue "File not executable: $SCRIPT_TO_TEST" "test -x $SCRIPT_TO_TEST"

  $SCRIPT_TO_TEST -d epagesj -o $OUTPUT
  assertTrue "Execution failed ($?): $SCRIPT_TO_TEST -d epagesj -o $OUTPUT" $?
  assertTrue "Output file missing: $OUTPUT" "test -f $OUTPUT"

  echo -e "done.\n"
}

##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
