#!/bin/bash

##############################################################################
# this script tests with shunit2 methods
# following shell script from the ../t dir
##############################################################################

SCRIPT_TO_TEST=mongo_keyfile.sh
INI_CONFIG=/var/epages/ini-config.sh

# die if shunit2 not found
type shunit2 && SHUNIT2=$(type -p shunit2) || exit 1
echo -e "testing: $0"
. /etc/default/epages6

# test script directory (/var/epages/t)
TEST_DIR=$(cd $(dirname $0) && pwd)
# directory to test (/var/epages/bin)
BIN_DIR=${TEST_DIR%/*}/bin
SCRIPT_TO_TEST=$BIN_DIR/$SCRIPT_TO_TEST
echo -e "script to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function setUp() {
  MONGO="mongo"

  #mongod_name() sourced by ../functions/fun-java.sh via /etc/default/epages6
  MONGO_CONF_FILE=${MONGOD_CONF:-"/etc/$(mongod_name).conf"}
  MONGO_CONF_FILE_COPY="/tmp/mongo.bak.conf"
  cp $MONGO_CONF_FILE $MONGO_CONF_FILE_COPY
}

function oneTimeTearDown() {
  rm $MONGO_CONF_FILE_COPY
  rm $TEST_KEY_FILE
}

##############################################################################
# define functions                                                           #
##############################################################################

function test_keyfile_generation() {
  $SCRIPT_TO_TEST -f $TEST_KEY_FILE -c $MONGO_CONF_FILE_COPY
  assertTrue "Invocation of 'mongo_keyfile.sh' failed." $?
  assertTrue "Could not create key file" '[ -s $TEST_KEY_FILE ]'

  CONFIG_KEY_FILE=$($INI_CONFIG -f $MONGO_CONF_FILE_COPY -k keyFile -G)
  CONFIG_AUTHORIZATION=$($INI_CONFIG -f $MONGO_CONF_FILE_COPY -k auth -G)
  assertEquals "Invalid value for key 'keyFile' in '$MONGO_CONF_FILE_COPY'." $TEST_KEY_FILE $CONFIG_KEY_FILE
  assertEquals "Invalid value for key 'auth' in '$MONGO_CONF_FILE_COPY'." 'true' $CONFIG_AUTHORIZATION

  echo -e "done.\n"
}


##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
